Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(574)

Unified Diff: ui/base/accelerators/accelerator_manager.h

Issue 2586333003: Make mash register initial batch of accelerators in single shot. (Closed)
Patch Set: Remove temporary vector. Add comments. Add AddAcceleratorToVector to use in OnAcceleratorRegistered… Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/base/accelerators/accelerator_manager.h
diff --git a/ui/base/accelerators/accelerator_manager.h b/ui/base/accelerators/accelerator_manager.h
index 9db9629fd8ecc8a9aabf7fa974fe15f1af2cdd75..796132c0d3e6162f7a372fb89a1d02805180790c 100644
--- a/ui/base/accelerators/accelerator_manager.h
+++ b/ui/base/accelerators/accelerator_manager.h
@@ -8,6 +8,7 @@
#include <list>
#include <map>
#include <utility>
+#include <vector>
#include "base/macros.h"
#include "ui/base/accelerators/accelerator.h"
@@ -30,10 +31,10 @@ class UI_BASE_EXPORT AcceleratorManager {
explicit AcceleratorManager(AcceleratorManagerDelegate* = nullptr);
~AcceleratorManager();
// Register a keyboard accelerator for the specified target. If multiple
// targets are registered for an accelerator, a target registered later has
// higher priority.
- // |accelerator| is the accelerator to register.
+ // |accelerators| contain accelerators to register.
// |priority| denotes the priority of the handler.
// NOTE: In almost all cases, you should specify kNormalPriority for this
// parameter. Setting it to kHighPriority prevents Chrome from sending the
@@ -47,7 +48,7 @@ class UI_BASE_EXPORT AcceleratorManager {
// - the enter key
// - any F key (F1, F2, F3 ...)
// - any browser specific keys (as available on special keyboards)
- void Register(const Accelerator& accelerator,
+ void Register(const std::vector<ui::Accelerator> accelerators,
HandlerPriority priority,
AcceleratorTarget* target);
@@ -30,10 +31,10 @@ class UI_BASE_EXPORT AcceleratorManager {
explicit AcceleratorManager(AcceleratorManagerDelegate* = nullptr);
~AcceleratorManager();
- // Register a keyboard accelerator for the specified target. If multiple
+ // Register keyboard accelerators for the specified target. If multiple
// targets are registered for an accelerator, a target registered later has
// higher priority.

Powered by Google App Engine
This is Rietveld 408576698